OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Du har skapat en ny tavla {board}",
    "{user} has created a new board {board}" : "{user} har skapat en ny tavla {board}",
    "You have deleted the board {board}" : "Du har raderat tavlan {board}",
    "{user} has deleted the board {board}" : "{user} har raderat tavlan {board}",
    "You have restored the board {board}" : "Du har återställt tavlan {board}",
    "{user} has restored the board {board}" : "{user} har återställt tavlan {board}",
    "You have shared the board {board} with {acl}" : "Du har delat tavlan {board} med {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} har delat tavlan {board} med {acl}",
    "You have removed {acl} from the board {board}" : "Du har raderat {acl} från tavlan {board}",
    "{user} has removed {acl} from the board {board}" : "{user} har raderat {acl} från tavlan {board}",
    "You have renamed the board {before} to {board}" : "Du har bytt namn på tavlan {before} till {board}",
    "{user} has renamed the board {before} to {board}" : "{user} har bytt namn på tavlan {before} till {board}",
    "You have archived the board {board}" : "Du har arkiverat tavlan {board}",
    "{user} has archived the board {before}" : "{user} har arkiverat tavlan {before}",
    "You have unarchived the board {board}" : "Du har avarkiverat tavlan {board}",
    "{user} has unarchived the board {before}" : "{user} har avarkiverat tavlan {before}",
    "You have renamed the card {before} to {card}" : "Du har bytt namn på kortet {before} till {card}",
    "{user} has renamed the card {before} to {card}" : "{user} har bytt namn på kortet {before} till {card}",
    "You have removed the due date of card {card}" : "Du har tagit bort förfallodatum för kortet {card}",
    "{user} has removed the due date of card {card}" : "{user} tagit bort förfallodatum för kortet {card}",
    "You have set the due date of card {card} to {after}" : "Du har satt förfallodatum för kortet {card} till {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} har satt förfallodatum för kortet {card} till {after}",
    "You have updated the due date of card {card} to {after}" : "Du har uppdaterat förfallodatum för kortet {card} till {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} har uppdaterat förfallodatum för kortet {card} till {after}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Du har tilldelat {assigneduser} till kortet {card} på tavlan {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} har tilldelat {assigneduser} till kortet {card} på tavlan {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Du har tagit bort tilldelningen för {assigneduser} från kortet {card} på tavlan {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} har tagit bort tilldelningen för {assigneduser} från kortet {card} på tavlan {board}",
    "You have added the attachment {attachment} to card {card}" : "Du har lagt till bilagan {attachment} till kortet {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} har lagt till bilagan {attachment} till kortet {card}",
    "You have updated the attachment {attachment} on card {card}" : "Du har uppdaterat bilagan {attachment} på kortet {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} har uppdaterat bilagan {attachment} på kortet {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Du har raderat bilagan {attachment} från kortet {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} har raderat bilagan {attachment} från kortet {card}",
    "You have restored the attachment {attachment} to card {card}" : "Du har återställt bilagan {attachment} till kortet {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} har återställt bilagan {attachment} till kortet {card}",
    "You have commented on card {card}" : "Du har kommenterat på kortet {card}",
    "{user} has commented on card {card}" : "{user} har kommenterat på kortet {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "En <strong>kortbeskrivning</strong> i Deck-appen har ändrats",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Ändringar i <strong>Deck-appen</strong>",
    "A <strong>comment</strong> was created on a card" : "En <strong>kommentar</strong> skapades på ett kort",
    "Personal" : "Personlig",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortet \"%s\" på \"%s\" har tilldelats dig av %s.",
    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} har tilldelat kortet \"%s\" på \"%s\" till dig.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Kortet \"%s\" på \"%s\" har nått sitt utgångsdatum.",
    "%s has mentioned you in a comment on \"%s\"." : "%s har nämnt dig i en kommentar på \"%s\".",
    "{user} has mentioned you in a comment on \"%s\"." : "{user} har nämnt dig i en kommentar på \"%s\".",
    "The board \"%s\" has been shared with you by %s." : "Tavlan \"%s\" har delats med dig av %s.",
    "{user} has shared the board %s with you." : "{user} har delat tavlan %s med dig.",
    "No data was provided to create an attachment." : "Inga data lämnades för att skapa en bilaga.",
    "Finished" : "Slutförd",
    "To review" : "Att granska",
    "Action needed" : "Åtgärd behövs",
    "Later" : "Senare",
    "copy" : "kopiera",
    "To do" : "Att göra",
    "Doing" : "Gör",
    "Done" : "Klart",
    "Example Task 3" : "Exempeluppgift 3",
    "Example Task 2" : "Exempeluppgift 2",
    "Example Task 1" : "Exempeluppgift 1",
    "The file was uploaded" : "Filen laddades upp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uppladdade filen överstiger direktivet upload_max_filesize i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uppladdade filen överstiger MAX_FILE_SIZE-direktivet som specificerades i HTML-formuläret",
    "The file was only partially uploaded" : "Filen var endast delvis uppladdad",
    "No file was uploaded" : "Ingen fil laddades upp",
    "Missing a temporary folder" : "Saknas en tillfällig mapp",
    "Could not write file to disk" : "Kunde inte skriva fil till disk",
    "A PHP extension stopped the file upload" : "Ett PHP-tillägg stoppade filuppladdningen",
    "No file uploaded or file size exceeds maximum of %s" : "Ingen fil uppladdad eller filstorleken överstiger max %s",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Korthögar är en kanban-liknande projekt- och organiseringsapp för arbetsgrupper i Nextcloud.\n\n\n- 📥 Lägg till uppgifter på kort och ordna dem\n- 📄 Skriv anteckningar i markdown\n- 🔖 Tilldela etiketter för organisering\n- 👥 Dela med arbetsgruppen, vänner eller familj\n- 📎 Bifoga filer och bädda in dem i markdown-anteckningarna\n- 💬 Diskutera i arbetsgruppen genom kommentarer\n- ⚡ Håll koll på ändringar i aktivitetsflödet\n- 🚀 Börja organisera din arbetsgrupp nu!",
    "Create new board" : "Skapa ny tavla",
    "new board" : "ny tavla",
    "Select the board to link to a project" : "Välj tavla att länka till ett projekt",
    "Search by board title" : "Sök efter namn på tavla",
    "Select board" : "Välj tavla",
    "Select the card to link to a project" : "Välj kort att länka till ett projekt",
    "Select a board" : "Välj en tavla",
    "Select a card" : "Välj ett kort",
    "Link to card" : "Länka till kort",
    "Cancel" : "Avbryt",
    "File already exists" : "Filen finns redan",
    "A file with the name {filename} already exists." : "En fil med namnet {filename} finns redan.",
    "Do you want to overwrite it?" : "Vill du skriva över det?",
    "Overwrite file" : "Skriv över filen",
    "Keep existing file" : "Behåll nuvarande fil",
    "This board is read only" : "Denna tavla är skrivskyddad",
    "Drop your files to upload" : "Släpp dina filer för att ladda upp",
    "Archived cards" : "Arkiverade kort",
    "Add new list" : "Lägg till en ny lista",
    "List name" : "Namn på lista",
    "Apply filter" : "Tillämpa filter",
    "Filter by tag" : "Filtrera efter tagg",
    "Filter by assigned user" : "Filtrera efter tilldelad användare",
    "Filter by due date" : "Filtrera efter förfallodatum",
    "Overdue" : "Förfallen",
    "Next 24 hours" : "Nästa 24 timmar",
    "Next 7 days" : "Nästa 7 dagar",
    "Next 30 days" : "Nästa 30 dagar",
    "No due date" : "Inget slutdatum",
    "Clear filter" : "Rensa filter",
    "Show archived cards" : "Visa arkiverade kort",
    "Toggle compact mode" : "Växla kompakt läge",
    "Details" : "Detaljer",
    "Loading board" : "Läser in tavla",
    "Board not found" : "Tavlan hittades inte",
    "Sharing" : "Delning",
    "Tags" : "Taggar",
    "Deleted items" : "Raderade objekt",
    "Timeline" : "Tidslinje",
    "Deleted lists" : "Raderade listor",
    "Undo" : "Ångra",
    "Deleted cards" : "Radera kort",
    "Share board with a user, group or circle …" : "Dela en tavla med en användare, grupp eller cirkel ...",
    "Board owner" : "Tavlans ägare",
    "(Group)" : "(Grupp)",
    "(Circle)" : "(Cirkel)",
    "Can edit" : "Kan redigera",
    "Can share" : "Kan dela",
    "Can manage" : "Kan hanter",
    "Delete" : "Radera",
    "Delete list" : "Radera lista",
    "Add card" : "Lägg till kort",
    "Add a new card" : "Lägg till ett nytt kort",
    "Edit" : "Redigera",
    "Add a new tag" : "Lägg till en ny tagg",
    "title and color value must be provided" : "titel och färg måste anges",
    "Title" : "Titel",
    "Members" : "Medlemmar",
    "Add this attachment" : "Lägg till denna bilaga",
    "Delete Attachment" : "Ta bort bilaga",
    "Restore Attachment" : "Återställ bilaga",
    "Assign a tag to this card…" : "Tilldela en tagg till det här kortet ...",
    "Assign to users" : "Tilldela till användare",
    "Assign to users/groups/circles" : "Tilldela till användare/grupper/cirklar",
    "Assign a user to this card…" : "Tilldela en användare till det här kortet ...",
    "Due date" : "Slutdatum",
    "Set a due date" : "Sätt ett slutdatum",
    "Remove due date" : "Ta bort slutdatum",
    "Description" : "Beskrivning",
    "(Unsaved)" : "(Inte sparad)",
    "(Saving…)" : "(Sparar…)",
    "Formatting help" : "Formatteringshjälp",
    "Edit description" : "Ändra beskrivning",
    "View description" : "Visa beskrivning",
    "Add Attachment" : "Lägg till bilaga",
    "Attachments" : "Bilagor",
    "Comments" : "Kommentarer",
    "Choose attachment" : "Välj bilaga",
    "Modified" : "Ändrad",
    "Created" : "Skapat",
    "Upload attachment" : "Ladda upp bilaga",
    "No comments yet. Begin the discussion!" : "Inga kommentarer än. Börja diskussionen!",
    "Save" : "Spara",
    "The comment cannot be empty." : "Kommentaren kan inte vara tom.",
    "The comment cannot be longer than 1000 characters." : "Kommentaren kan inte vara längre än 1000 tecken.",
    "In reply to" : "Som svar på",
    "Reply" : "Svara",
    "Update" : "Uppdatera",
    "(group)" : " (grupp)",
    "(circle)" : "(cirkel)",
    "seconds ago" : "sekunder sedan",
    "Assign to me" : "Tilldela till mig",
    "Unarchive card" : "Avarkivera kort",
    "Archive card" : "Arkivera kort",
    "Delete card" : "Ta bort kort",
    "Move card" : "Flytta kort",
    "Card details" : "Kortdetaljer",
    "Move card to another board" : "Flytta kort till en annan tavla",
    "All boards" : "Alla tavlor",
    "Archived boards" : "Arkiverade tavlor",
    "Shared with you" : "Delad med dig",
    "Limit deck usage of groups" : "Begränsa användningen av grupper",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begränsa Deck blockerar användare som inte ingår i dessa grupper från att skapa egna tavlor. Användare kan fortfarande arbeta med tavlor som har delats med dem.",
    "New board title" : "Ny titel för tavla",
    "Edit board" : "Ändra tavla",
    "Clone board " : "Kopiera tavla",
    "Unarchive board " : "Ta bort tavlan ur arkivet",
    "Archive board " : "Arkivera tavla",
    "Delete board " : "Radera tavla",
    "Board details" : "Taveldetaljer",
    "Board {0} deleted" : "Tavla {0} raderad",
    "An error occurred" : "Ett fel uppstod",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Är du säker på att du vill radera tavla {title}? Detta kommer att radera all information från denna tavla.",
    "Delete the board?" : "Radera tavlan?",
    "Link to a board" : "Länka till en tavla",
    "Link to a card" : "Länka till ett kort",
    "Something went wrong" : "Något gick fel",
    "Maximum file size of {size} exceeded" : "Maximal filstorlek på {size} överskriden"
},
"nplurals=2; plural=(n != 1);");
